package com.ruoyi.bid.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bid.mapper.BidCompanyMapper;
import com.ruoyi.bid.domain.BidCompany;
import com.ruoyi.bid.service.IBidCompanyService;

/**
 * 公司信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-12-10
 */
@Service
public class BidCompanyServiceImpl implements IBidCompanyService 
{
    @Autowired
    private BidCompanyMapper bidCompanyMapper;

    /**
     * 查询公司信息
     * 
     * @param id 公司信息主键
     * @return 公司信息
     */
    @Override
    public BidCompany selectBidCompanyById(Long id)
    {
        return bidCompanyMapper.selectBidCompanyById(id);
    }

    /**
     * 查询公司信息列表
     * 
     * @param bidCompany 公司信息
     * @return 公司信息
     */
    @Override
    public List<BidCompany> selectBidCompanyList(BidCompany bidCompany)
    {
        return bidCompanyMapper.selectBidCompanyList(bidCompany);
    }

    /**
     * 新增公司信息
     * 
     * @param bidCompany 公司信息
     * @return 结果
     */
    @Override
    public int insertBidCompany(BidCompany bidCompany)
    {
        return bidCompanyMapper.insertBidCompany(bidCompany);
    }

    /**
     * 修改公司信息
     * 
     * @param bidCompany 公司信息
     * @return 结果
     */
    @Override
    public int updateBidCompany(BidCompany bidCompany)
    {
        return bidCompanyMapper.updateBidCompany(bidCompany);
    }

    /**
     * 批量删除公司信息
     * 
     * @param ids 需要删除的公司信息主键
     * @return 结果
     */
    @Override
    public int deleteBidCompanyByIds(Long[] ids)
    {
        return bidCompanyMapper.deleteBidCompanyByIds(ids);
    }

    /**
     * 删除公司信息信息
     * 
     * @param id 公司信息主键
     * @return 结果
     */
    @Override
    public int deleteBidCompanyById(Long id)
    {
        return bidCompanyMapper.deleteBidCompanyById(id);
    }
}
